import { jsx as _jsx, jsxs as _jsxs, Fragment as _Fragment } from "react/jsx-runtime";
import { AppBar, Button, Divider, Hidden, IconButton, ListItemButton, ListItemIcon, ListItemText, Menu, Toolbar, Tooltip, useMediaQuery, } from "@mui/material";
import { alpha, styled, useTheme } from "@mui/system";
import * as React from "react";
import { Link } from "react-router-dom";
/**
 * @component
 * @param {string} title title of the app
 * @param {string} logo Logo of the app
 * @param {string} variant Size of the appBar (dense or regular)
 * @param {Array<NerdAppBarContent | JSX.Element>} content Height of the appbar. Could be dense or regular.
 * @returns {JsxElement} UserDisplay component
 */
export function NerdAppBar({ title, logo, content = [], variant = "regular", }) {
    return (_jsxs(AppBar, Object.assign({ position: "fixed", sx: {
            zIndex: (theme) => theme.zIndex.drawer + 1,
            background: (theme) => theme.palette.background.default,
        }, elevation: 0, color: "transparent" }, { children: [_jsxs(Toolbar, Object.assign({ variant: variant }, { children: [_jsxs(Button, Object.assign({ href: "/", sx: { color: "text.primary" } }, { children: [_jsx("img", { alt: "logo", src: logo, height: variant === "dense" ? "30px" : "45px" }, void 0), _jsx(Hidden, Object.assign({ smDown: true }, { children: title }), void 0)] }), void 0), _jsx(Divider, { sx: { m: 1 }, orientation: "vertical", flexItem: true }, void 0), content.map((c) => {
                        if (isNerdAppBarContent(c))
                            return _jsx(NerdAppBarMenuItem, Object.assign({}, c), void 0);
                        return c;
                    })] }), void 0), _jsx(Divider, {}, void 0)] }), void 0));
}
/**
 *
 * @param toTest element you want to know if it has the NerdAppBarContent type
 * @returns {boolean}
 */
function isNerdAppBarContent(toTest) {
    return toTest.title !== undefined;
}
/**
 * @param {NerdAppBarContent} c Content of the menu item
 * @returns {JSX.Element} the menu
 **/
export function NerdAppBarMenuItem(c) {
    const theme = useTheme();
    const md = useMediaQuery(theme.breakpoints.up("md"));
    const [anchorEl, setAnchorEl] = React.useState(null);
    const open = Boolean(anchorEl);
    const handleClick = (event) => {
        setAnchorEl(event.currentTarget);
    };
    const handleClose = () => {
        setAnchorEl(null);
    };
    let buttonProps = {
        onClick: c.nested ? handleClick : c.callback,
    };
    if (c.href) {
        buttonProps = {
            component: Link,
            to: c.href,
        };
    }
    return (_jsxs(_Fragment, { children: [c.divider ? (_jsx(Divider, { sx: { m: 1 }, orientation: "vertical", flexItem: true }, void 0)) : ([]), md ? (_jsx(Button, Object.assign({}, c, buttonProps, { children: c.title }), void 0)) : (_jsx(Tooltip, Object.assign({ title: `${c.title}` }, { children: _jsx(IconButton, Object.assign({}, c, { color: "primary", size: "small" }, buttonProps, { children: c.startIcon }), void 0) }), void 0)), c.nested ? (_jsx(StyledMenu, Object.assign({ id: "basic-menu", anchorEl: anchorEl, open: open, onClose: handleClose, anchorOrigin: {
                    vertical: "bottom",
                    horizontal: "right",
                }, transformOrigin: {
                    vertical: "top",
                    horizontal: "center",
                }, MenuListProps: {
                    "aria-labelledby": "basic-button",
                } }, { children: c.nested.map((n) => {
                    let buttonProps = {};
                    if (c.href) {
                        buttonProps = {
                            component: Link,
                            to: c.href,
                        };
                    }
                    return (_jsxs(ListItemButton, Object.assign({ dense: true, divider: n.divider }, buttonProps, { children: [typeof n.icon === "string" ? (_jsx("div", Object.assign({ className: "faicon" }, { children: _jsx("i", { className: n.icon }, void 0) }), void 0)) : (_jsx(ListItemIcon, { children: n.icon }, void 0)), _jsx(ListItemText, { primary: n.title, secondary: n.subtitle }, void 0)] }), void 0));
                }) }), void 0)) : ([])] }, void 0));
}
const StyledMenu = styled((props) => (_jsx(Menu, Object.assign({ elevation: 0, anchorOrigin: {
        vertical: "bottom",
        horizontal: "right",
    }, transformOrigin: {
        vertical: "top",
        horizontal: "right",
    } }, props), void 0)))(({ theme }) => ({
    "& .MuiPaper-root": {
        borderRadius: 6,
        marginTop: 10,
        background: theme.palette.mode === "light" ? "white" : theme.palette.grey[900],
        minWidth: 180,
        color: theme.palette.mode === "light"
            ? "rgb(55, 65, 81)"
            : theme.palette.grey[300],
        boxShadow: "rgb(255, 255, 255) 0px 0px 0px 0px, rgba(0, 0, 0, 0.05) 0px 0px 0px 1px, rgba(0, 0, 0, 0.1) 0px 10px 15px -3px, rgba(0, 0, 0, 0.05) 0px 4px 6px -2px",
        "& .MuiMenu-list": {
            padding: "4px 0",
        },
        "& .MuiMenuItem-root": {
            "& .MuiSvgIcon-root": {
                fontSize: 18,
                color: theme.palette.text.secondary,
                marginRight: theme.spacing(1.5),
            },
            "&:active": {
                backgroundColor: alpha(theme.palette.primary.main, theme.palette.action.selectedOpacity),
            },
        },
    },
}));
